@@ -4,6 +4,7 @@ import sys
 import inspect
 import os.path
 
+import boto3
 import click
 import requests
 from io import StringIO
@@ -110,73 +111,17 @@ def unpack_range(s):
 
 @click.command()
 @click.option('--file',
-              default='/home/martin/Downloads/hathi_full_20230101.txt',
-              help='The Hathitrust full dump to use')
+              default='hathi_full_20230101.txt',
+              help='The filename of the Hathitrust full dump to use')
+@click.option('--bucket',
+              default='preservation.research.crossref.org',
+              help='The s3 bucket from which to retrieve the data')
 @transaction.atomic()
-def import_hathi(file):
-    """Import data from Hathi (requires local file download)"""
-    log.info('[green]Opening:[/] Hathi data', extra={'markup': True})
-    # clear out
-    log.info('[green]Clearing:[/] previous Hathi data',
-             extra={'markup': True})
-    HathiPreservation.objects.all().delete()
-
-    csv.field_size_limit(sys.maxsize)
-
-    with open(file) as input_file:
-        csv_reader = csv.reader(input_file, delimiter='\t')
-
-        volume_matcher = r'v\.\s?(\d+(?:\-?\d+)?)'
-        no_matcher = r'no\.\s?(\d+(?:\-?\d+)?)'
-        year_matcher = r'\d{4}'
-
-        for row in csv_reader:
-            try:
-                vols = row[4]
-                issn = row[9]
-                title = row[11]
-                publishing_info = row[12]
-                date = row[16]
-                bf = row[19]
-                unknown_format = False
-
-                # if it's a serial, try to parse the vols
-                if bf == 'SE' and issn and vols:
-                    matches = re.findall(volume_matcher, vols)
-
-                    if matches:
-                        for match in matches:
-                            vols = unpack_range(match)
-                    else:
-                        matches = re.findall(no_matcher, vols)
-
-                        if matches:
-                            for match in matches:
-                                vols = unpack_range(match)
-                        else:
-
-                            matches = re.findall(year_matcher, vols)
-
-                            if matches:
-                                for match in matches:
-                                    vols = match
-                            else:
-                                unknown_format = True
-
-                    if not unknown_format:
-                        if title.endswith('.'):
-                            title = title[:-1]
-
-                        HathiPreservation.objects.create(
-                            issn=issn,
-                            title=title,
-                            preserved_volumes=vols
-                        )
-
-                        log.info('[green]Added:[/] {} to Hathi'.format(title),
-                                 extra={'markup': True})
-            except IndexError:
-                pass
+def import_hathi(file, bucket):
+    """Import data from Hathi (requires local file download or S3)"""
+    s3client = boto3.client('s3')
+    HathiPreservation.import_data(
+        file, bucket=bucket, s3client=s3client)
 
 
 @click.command()
