@@ -140,7 +140,11 @@ def clear_out(model):
     model.objects.all().delete()
 
 
-def download_remote(local, model, url):
+def download_remote(local, model, url, bucket="", s3client=None):
+    if s3client:
+        return s3client.get_object(Bucket=bucket, Key=url)[
+            'Body'].read().decode('utf-8')
+
     if not local:
         logging.info(f'Downloading: {model.name()} data')
         csv_file = requests.get(url).text
